summaryrefslogtreecommitdiff
path: root/nest/proto-hooks.c
diff options
context:
space:
mode:
Diffstat (limited to 'nest/proto-hooks.c')
-rw-r--r--nest/proto-hooks.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nest/proto-hooks.c b/nest/proto-hooks.c
index 71cddd64..bc88b4b4 100644
--- a/nest/proto-hooks.c
+++ b/nest/proto-hooks.c
@@ -258,16 +258,16 @@ void store_tmp_attrs(rte *e, ea_list *attrs)
{ DUMMY; }
/**
* import_control - pre-filtering decisions on route import
* @p: protocol instance the route is going to be imported to
* @e: the route in question
* @attrs: extended attributes of the route
* @pool: linear pool for allocation of all temporary data
*
* The import_control() hook is called as the first step of a exporting
* a route from a routing table to the protocol instance. It can modify
- * route attributes and force acceptance or rejection of the route regardless
- * of user-specified filters. See rte_announce() for a complete description
+ * route attributes and force acceptance or rejection of the route before
+ * the user-specified filters are run. See rte_announce() for a complete description
* of the route distribution process.
*
* The standard use of this hook is to reject routes having originated
@@ -276,7 +276,7 @@ void store_tmp_attrs(rte *e, ea_list *attrs)
* Result: 1 if the route has to be accepted, -1 if rejected and 0 if it
* should be passed to the filters.
*/
-int import_control(struct proto *p, rte **e, ea_list **attrs, struct linpool *pool)
+int preexport(struct proto *p, rte **e, ea_list **attrs, struct linpool *pool)
{ DUMMY; }
/**
@@ -258,16 +258,16 @@ void store_tmp_attrs(rte *e, ea_list *attrs)
{ DUMMY; }
/**
- * import_control - pre-filtering decisions on route import
- * @p: protocol instance the route is going to be imported to
+ * preexport - pre-filtering decisions before route export
+ * @p: protocol instance the route is going to be exported to
* @e: the route in question
* @attrs: extended attributes of the route
@@ -258,16 +258,16 @@ void store_tmp_attrs(rte *e, ea_list *attrs)
* @pool: linear pool for allocation of all temporary data
*
- * The import_control() hook is called as the first step of a exporting
+ * The preexport() hook is called as the first step of a exporting
* a route from a routing table to the protocol instance. It can modify